==> peppol-busdox-1.0.0-sources.jar: org/busdox/transport/identifiers/_1/ObjectFactory.java <==

package org.busdox.transport.identifiers._1;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.busdox.transport.identifiers._1 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _DocumentIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "DocumentIdentifier");
    private final static QName _ChannelIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "ChannelIdentifier");
    private final static QName _SenderIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "SenderIdentifier");
    private final static QName _MessageIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "MessageIdentifier");
    private final static QName _ProcessIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "ProcessIdentifier");
    private final static QName _RecipientIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "RecipientIdentifier");
    private final static QName _ParticipantIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "ParticipantIdentifier");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.busdox.transport.identifiers._1
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ParticipantIdentifierType }
     * 
     */
    public ParticipantIdentifierType createParticipantIdentifierType() {
        return new ParticipantIdentifierType();
    }

    /**
     * Create an instance of {@link DocumentIdentifierType }
     * 
     */
    public DocumentIdentifierType createDocumentIdentifierType() {
        return new DocumentIdentifierType();
    }

    /**
     * Create an instance of {@link ProcessIdentifierType }
     * 
     */
    public ProcessIdentifierType createProcessIdentifierType() {
        return new ProcessIdentifierType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DocumentIdentifierType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "DocumentIdentifier")
    public JAXBElement<DocumentIdentifierType> createDocumentIdentifier(DocumentIdentifierType value) {
        return new JAXBElement<DocumentIdentifierType>(_DocumentIdentifier_QNAME, DocumentIdentifierType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "ChannelIdentifier")
    public JAXBElement<String> createChannelIdentifier(String value) {
        return new JAXBElement<String>(_ChannelIdentifier_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ParticipantIdentifierType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "SenderIdentifier")
    public JAXBElement<ParticipantIdentifierType> createSenderIdentifier(ParticipantIdentifierType value) {
        return new JAXBElement<ParticipantIdentifierType>(_SenderIdentifier_QNAME, ParticipantIdentifierType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "MessageIdentifier")
    public JAXBElement<String> createMessageIdentifier(String value) {
        return new JAXBElement<String>(_MessageIdentifier_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ProcessIdentifierType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "ProcessIdentifier")
    public JAXBElement<ProcessIdentifierType> createProcessIdentifier(ProcessIdentifierType value) {
        return new JAXBElement<ProcessIdentifierType>(_ProcessIdentifier_QNAME, ProcessIdentifierType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ParticipantIdentifierType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "RecipientIdentifier")
    public JAXBElement<ParticipantIdentifierType> createRecipientIdentifier(ParticipantIdentifierType value) {
        return new JAXBElement<ParticipantIdentifierType>(_RecipientIdentifier_QNAME, ParticipantIdentifierType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ParticipantIdentifierType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "ParticipantIdentifier")
    public JAXBElement<ParticipantIdentifierType> createParticipantIdentifier(ParticipantIdentifierType value) {
        return new JAXBElement<ParticipantIdentifierType>(_ParticipantIdentifier_QNAME, ParticipantIdentifierType.class, null, value);
    }

}

==> peppol-busdox-2.1.0-sources.jar: org/busdox/transport/identifiers/_1/ObjectFactory.java <==

package org.busdox.transport.identifiers._1;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.busdox.transport.identifiers._1 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _ParticipantIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "ParticipantIdentifier");
    private final static QName _DocumentIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "DocumentIdentifier");
    private final static QName _ProcessIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "ProcessIdentifier");
    private final static QName _RecipientIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "RecipientIdentifier");
    private final static QName _SenderIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "SenderIdentifier");
    private final static QName _MessageIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "MessageIdentifier");
    private final static QName _ChannelIdentifier_QNAME = new QName("http://busdox.org/transport/identifiers/1.0/", "ChannelIdentifier");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.busdox.transport.identifiers._1
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ParticipantIdentifierType }
     * 
     */
    public ParticipantIdentifierType createParticipantIdentifierType() {
        return new ParticipantIdentifierType();
    }

    /**
     * Create an instance of {@link DocumentIdentifierType }
     * 
     */
    public DocumentIdentifierType createDocumentIdentifierType() {
        return new DocumentIdentifierType();
    }

    /**
     * Create an instance of {@link ProcessIdentifierType }
     * 
     */
    public ProcessIdentifierType createProcessIdentifierType() {
        return new ProcessIdentifierType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ParticipantIdentifierType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ParticipantIdentifierType }{@code >}
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "ParticipantIdentifier")
    public JAXBElement<ParticipantIdentifierType> createParticipantIdentifier(ParticipantIdentifierType value) {
        return new JAXBElement<ParticipantIdentifierType>(_ParticipantIdentifier_QNAME, ParticipantIdentifierType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DocumentIdentifierType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link DocumentIdentifierType }{@code >}
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "DocumentIdentifier")
    public JAXBElement<DocumentIdentifierType> createDocumentIdentifier(DocumentIdentifierType value) {
        return new JAXBElement<DocumentIdentifierType>(_DocumentIdentifier_QNAME, DocumentIdentifierType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ProcessIdentifierType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ProcessIdentifierType }{@code >}
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "ProcessIdentifier")
    public JAXBElement<ProcessIdentifierType> createProcessIdentifier(ProcessIdentifierType value) {
        return new JAXBElement<ProcessIdentifierType>(_ProcessIdentifier_QNAME, ProcessIdentifierType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ParticipantIdentifierType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ParticipantIdentifierType }{@code >}
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "RecipientIdentifier")
    public JAXBElement<ParticipantIdentifierType> createRecipientIdentifier(ParticipantIdentifierType value) {
        return new JAXBElement<ParticipantIdentifierType>(_RecipientIdentifier_QNAME, ParticipantIdentifierType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ParticipantIdentifierType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ParticipantIdentifierType }{@code >}
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "SenderIdentifier")
    public JAXBElement<ParticipantIdentifierType> createSenderIdentifier(ParticipantIdentifierType value) {
        return new JAXBElement<ParticipantIdentifierType>(_SenderIdentifier_QNAME, ParticipantIdentifierType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "MessageIdentifier")
    public JAXBElement<String> createMessageIdentifier(String value) {
        return new JAXBElement<String>(_MessageIdentifier_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://busdox.org/transport/identifiers/1.0/", name = "ChannelIdentifier")
    public JAXBElement<String> createChannelIdentifier(String value) {
        return new JAXBElement<String>(_ChannelIdentifier_QNAME, String.class, null, value);
    }

}
